@@ -3,10 +3,10 @@
 # @package      hubzero-submit-distributor
 # @file         Scripts/ll/cleanupjob.sh
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright 2004-2012 HUBzero Foundation, LLC.
+# @copyright    Copyright 2004-2013 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2004-2012 HUBzero Foundation, LLC.
+# Copyright (c) 2004-2013 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -26,13 +26,16 @@
 #
 # HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
-if [ $# -ne 1 ] ; then
-   echo usage: $0 jobWorkingDirectory
+if [ $# -ne 3 ] ; then
+   echo usage: $0 jobWorkingDirectory jobScratchDirectory jobClass
    exit 64
 fi
 
-rm -rf $1
+jobWorkingDirectory=$1
+jobScratchDirectory=$2
+jobClass=$3
+
+rm -rf ${jobWorkingDirectory}
 exitStatus=$?
 
-exit $exitStatus
-
+exit ${exitStatus}
