@@ -3,10 +3,10 @@
 # @package      hubzero-submit-distributor
 # @file         Scripts/pbs/transmitresults.sh
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright 2004-2012 HUBzero Foundation, LLC.
+# @copyright    Copyright 2004-2013 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2004-2012 HUBzero Foundation, LLC.
+# Copyright (c) 2004-2013 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -31,14 +31,15 @@ if [ $# -ne 1 ] ; then
    exit 64
 fi
 
-cd $1
+jobWorkingDirectory=$1
+
+cd ${jobWorkingDirectory}
 exitStatus=$?
 
-if [ $exitStatus -eq 0 ] ; then
+if [ ${exitStatus} -eq 0 ] ; then
 # Allow for file/directory names with embedded spaces.
    find . -newer .__fileTimeMarker -not -name . -print0 | xargs --null tar czf -
    exitStatus=$?
 fi
 
-exit $exitStatus
-
+exit ${exitStatus}
